Name:          liblive
Summary:       Live.com streaming libraries
Version:       2022.04.26
Release:       1mamba
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           http://www.live555.com/liveMedia/
Source:        http://www.live555.com/liveMedia/public/live.%{version}.tar.gz
License:       LGPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libopenssl-devel
BuildRequires: libstdc++6-devel
## AUTOBUILDREQ-END

%description
This code forms a set of C++ libraries for multimedia streaming, using open standard protocols (RTP/RTCP, RTSP, SIP). These libraries - which can be compiled for Unix (including Linux and Mac OS X), Windows, and QNX (and other POSIX-compliant systems) - can be used to build streaming applications.
The libraries can also be used to stream, receive, and process MPEG, H.263+ or JPEG video, and several audio codecs. They can easily be extended to support additional (audio and/or video) codecs, and can also be used to build basic RTSP or SIP clients and servers, and have been used to add streaming support to existing media player applications.

%package devel
Summary:       Live.com streaming libraries for development
Group:         Development/Libraries
Provides:      liblive
Obsoletes:     liblive < 2021.05.22

%description devel
This code forms a set of C++ libraries for multimedia streaming, using open standard protocols (RTP/RTCP, RTSP, SIP). These libraries - which can be compiled for Unix (including Linux and Mac OS X), Windows, and QNX (and other POSIX-compliant systems) - can be used to build streaming applications.
The libraries can also be used to stream, receive, and process MPEG, H.263+ or JPEG video, and several audio codecs. They can easily be extended to support additional (audio and/or video) codecs, and can also be used to build basic RTSP or SIP clients and servers, and have been used to add streaming support to existing media player applications.
This package contains static libraries and header files need for development.

#% debug_package

%prep
%setup -q -n live
## edit each Makefile to replace each occurrence of ")$" with ") $".
##find . -name 'Makefile' -exec fix-makefile {} \;

%build
./genMakefiles linux

make
## for gcc>= 3.0: "You may also wish to add the -Wno-deprecated flag to CPLUSPLUS_FLAGS."
make -C testProgs CPLUSPLUS_COMPILER=g++ -Wno-deprecated LINK=g++ all

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
# ??
mkdir -p %{buildroot}%{_bindir}

# There is no make install!
SUBDIRS="BasicUsageEnvironment groupsock liveMedia UsageEnvironment"
for i in $SUBDIRS; do
	mkdir -p %{buildroot}%{_libdir}/live/$i;
	# .a
	install -m 644 `find $i -name \*.a` \
		%{buildroot}%{_libdir}/live/$i;
	# .hh, .h
	mkdir -p %{buildroot}%{_includedir}/$i;
	install -m 644 `find $i -name \*.hh -or -name \*.h` \
		%{buildroot}%{_includedir}/$i;
done;

mkdir -p %{buildroot}%{_includedir}/mediaServer
mkdir -p %{buildroot}%{_libdir}/live/mediaServer

install -m 644 `find WindowsAudioInputDevice -name \*.hh -or -name \*.h` \
		%{buildroot}%{_includedir}/mediaServer;

install -m 755 mediaServer/live555MediaServer %{buildroot}%{_libdir}/live/mediaServer
install -m 644 `find mediaServer -name \*.hh -or -name \*.h` \
		%{buildroot}%{_includedir}/mediaServer;

mkdir -p %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/MPEG2TransportStreamIndexer %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/openRTSP %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/playSIP %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/sapWatch %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testAMRAudioStreamer %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMP3Receiver %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMP3Streamer %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMPEG1or2AudioVideoStreamer %{buildroot}%{_libdir}/live/testProgs
#install -m 755 testProgs/testMPEG1or2AudioVideoToDarwin %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMPEG1or2ProgramToTransportStream %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMPEG1or2Splitter %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMPEG1or2VideoReceiver %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMPEG1or2VideoStreamer %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMPEG2TransportStreamer %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMPEG2TransportStreamTrickPlay %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testMPEG4VideoStreamer %{buildroot}%{_libdir}/live/testProgs
#install -m 755 testProgs/testMPEG4VideoToDarwin %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testOnDemandRTSPServer %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testRelay %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/testWAVAudioStreamer %{buildroot}%{_libdir}/live/testProgs
install -m 755 testProgs/vobStreamer %{buildroot}%{_libdir}/live/testProgs

mkdir -p %{buildroot}%{_includedir}/UsageEnvironment
install -m 644 UsageEnvironment/libUsageEnvironment.a %{buildroot}%{_libdir}/live/UsageEnvironment
install -m 644 `find UsageEnvironment/include -name \*.hh -or -name \*.h` \
		%{buildroot}%{_includedir}/UsageEnvironment;

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%files devel
%defattr(-,root,root,0755)
%dir %{_libdir}/live/BasicUsageEnvironment
%{_libdir}/live/BasicUsageEnvironment/libBasicUsageEnvironment.a
%dir %{_includedir}/BasicUsageEnvironment
%{_includedir}/BasicUsageEnvironment/*.hh
%dir %{_libdir}/live/UsageEnvironment
%{_libdir}/live/UsageEnvironment/libUsageEnvironment.a
%dir %{_includedir}/UsageEnvironment
%{_includedir}/UsageEnvironment/*.hh
%dir %{_libdir}/live/groupsock
%{_libdir}/live/groupsock/libgroupsock.a
%dir %{_includedir}/groupsock
%{_includedir}/groupsock/*.h
%{_includedir}/groupsock/*.hh
%dir %{_libdir}/live/liveMedia
%{_libdir}/live/liveMedia/libliveMedia.a
%dir %{_includedir}/liveMedia
%{_includedir}/liveMedia/*.hh
%{_includedir}/liveMedia/*.h
%dir %{_includedir}/mediaServer
%{_includedir}/mediaServer/*.hh
# binary
%{_libdir}/live/mediaServer/live555MediaServer
%dir %{_libdir}/live/testProgs
%{_libdir}/live/testProgs/MPEG2TransportStreamIndexer
%{_libdir}/live/testProgs/openRTSP
%{_libdir}/live/testProgs/playSIP
%{_libdir}/live/testProgs/sapWatch
%{_libdir}/live/testProgs/testAMRAudioStreamer
%{_libdir}/live/testProgs/testMP3Receiver
%{_libdir}/live/testProgs/testMP3Streamer
%{_libdir}/live/testProgs/testMPEG1or2AudioVideoStreamer
#%{_libdir}/live/testProgs/testMPEG1or2AudioVideoToDarwin
%{_libdir}/live/testProgs/testMPEG1or2ProgramToTransportStream
%{_libdir}/live/testProgs/testMPEG1or2Splitter
%{_libdir}/live/testProgs/testMPEG1or2VideoReceiver
%{_libdir}/live/testProgs/testMPEG1or2VideoStreamer
%{_libdir}/live/testProgs/testMPEG2TransportStreamTrickPlay
%{_libdir}/live/testProgs/testMPEG2TransportStreamer
%{_libdir}/live/testProgs/testMPEG4VideoStreamer
#%{_libdir}/live/testProgs/testMPEG4VideoToDarwin
%{_libdir}/live/testProgs/testOnDemandRTSPServer
%{_libdir}/live/testProgs/testRelay
%{_libdir}/live/testProgs/testWAVAudioStreamer
%{_libdir}/live/testProgs/vobStreamer
%doc COPYING README

%changelog
* Tue Apr 26 2022 Automatic Build System <autodist@mambasoft.it> 2022.04.26-1mamba
- automatic version update by autodist

* Fri Apr 15 2022 Automatic Build System <autodist@mambasoft.it> 2022.04.15-1mamba
- automatic version update by autodist

* Thu Apr 14 2022 Automatic Build System <autodist@mambasoft.it> 2022.04.12-1mamba
- automatic version update by autodist

* Tue Feb 08 2022 Automatic Build System <autodist@mambasoft.it> 2022.02.07-1mamba
- automatic version update by autodist

* Fri Jan 21 2022 Automatic Build System <autodist@mambasoft.it> 2022.01.21-1mamba
- automatic version update by autodist

* Fri Jan 21 2022 Automatic Build System <autodist@mambasoft.it> 2022.01.20-1mamba
- automatic version update by autodist

* Tue Jan 18 2022 Automatic Build System <autodist@mambasoft.it> 2022.01.17-1mamba
- automatic version update by autodist

* Thu Jan 13 2022 Automatic Build System <autodist@mambasoft.it> 2022.01.11-1mamba
- automatic version update by autodist

* Fri Jan 07 2022 Automatic Build System <autodist@mambasoft.it> 2022.01.06-1mamba
- automatic version update by autodist

* Sun Dec 19 2021 Automatic Build System <autodist@mambasoft.it> 2021.12.18-1mamba
- automatic version update by autodist

* Wed Dec 08 2021 Automatic Build System <autodist@mambasoft.it> 2021.12.07-1mamba
- automatic version update by autodist

* Wed Nov 24 2021 Automatic Build System <autodist@mambasoft.it> 2021.11.23-1mamba
- automatic version update by autodist

* Mon Nov 15 2021 Automatic Build System <autodist@mambasoft.it> 2021.11.14-1mamba
- automatic version update by autodist

* Thu Nov 11 2021 Automatic Build System <autodist@mambasoft.it> 2021.11.10-1mamba
- automatic version update by autodist

* Tue Nov 02 2021 Automatic Build System <autodist@mambasoft.it> 2021.11.01-1mamba
- automatic version update by autodist

* Sun Oct 31 2021 Automatic Build System <autodist@mambasoft.it> 2021.10.31-1mamba
- automatic version update by autodist

* Fri Oct 29 2021 Automatic Build System <autodist@mambasoft.it> 2021.10.28-1mamba
- automatic version update by autodist

* Thu Oct 21 2021 Automatic Build System <autodist@mambasoft.it> 2021.10.20-1mamba
- automatic version update by autodist

* Wed Aug 25 2021 Automatic Build System <autodist@mambasoft.it> 2021.08.24-1mamba
- automatic version update by autodist

* Mon Aug 23 2021 Automatic Build System <autodist@mambasoft.it> 2021.08.23-1mamba
- automatic version update by autodist

* Fri Aug 20 2021 Automatic Build System <autodist@mambasoft.it> 2021.08.19-1mamba
- automatic version update by autodist

* Sun Aug 15 2021 Automatic Build System <autodist@mambasoft.it> 2021.08.14-1mamba
- automatic version update by autodist

* Mon Aug 09 2021 Automatic Build System <autodist@mambasoft.it> 2021.08.09-1mamba
- automatic version update by autodist

* Mon Aug 09 2021 Automatic Build System <autodist@mambasoft.it> 2021.08.06-1mamba
- automatic version update by autodist

* Wed Aug 04 2021 Automatic Build System <autodist@mambasoft.it> 2021.08.04-1mamba
- automatic version update by autodist

* Wed Jul 21 2021 Automatic Build System <autodist@mambasoft.it> 2021.07.20-1mamba
- automatic version update by autodist

* Sat Jul 10 2021 Automatic Build System <autodist@mambasoft.it> 2021.07.10-1mamba
- automatic version update by autodist

* Wed Jun 30 2021 Automatic Build System <autodist@mambasoft.it> 2021.06.29-1mamba
- automatic version update by autodist

* Fri Jun 25 2021 Automatic Build System <autodist@mambasoft.it> 2021.06.25-1mamba
- automatic version update by autodist

* Tue Jun 01 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 2021.05.22-1mamba
- update to 2021.05.22

* Tue May 04 2021 Automatic Build System <autodist@mambasoft.it> 2021.05.03-1mamba
- automatic version update by autodist

* Thu Apr 08 2021 Automatic Build System <autodist@mambasoft.it> 2021.04.06-1mamba
- automatic version update by autodist

* Wed Mar 24 2021 Automatic Build System <autodist@mambasoft.it> 2021.03.22-1mamba
- automatic version update by autodist

* Fri Mar 19 2021 Automatic Build System <autodist@mambasoft.it> 2021.03.17-1mamba
- automatic version update by autodist

* Tue Mar 16 2021 Automatic Build System <autodist@mambasoft.it> 2021.03.16-1mamba
- automatic version update by autodist

* Tue Mar 16 2021 Automatic Build System <autodist@mambasoft.it> 2021.03.15-1mamba
- automatic version update by autodist

* Sat Feb 13 2021 Automatic Build System <autodist@mambasoft.it> 2021.02.11-1mamba
- automatic version update by autodist

* Thu Feb 11 2021 Automatic Build System <autodist@mambasoft.it> 2021.02.10-1mamba
- automatic version update by autodist

* Sun Jun 07 2020 Automatic Build System <autodist@mambasoft.it> 2020.05.15-1mamba
- automatic update by autodist

* Fri Aug 02 2019 Automatic Build System <autodist@mambasoft.it> 2019.07.27-1mamba
- automatic update by autodist

* Tue Feb 02 2016 Automatic Build System <autodist@mambasoft.it> 2016.01.29-1mamba
- automatic update by autodist

* Wed May 27 2015 Automatic Build System <autodist@mambasoft.it> 2015.05.25-1mamba
- automatic update by autodist

* Sat May 23 2015 Automatic Build System <autodist@mambasoft.it> 2015.05.12-1mamba
- automatic update by autodist

* Fri May 08 2015 Automatic Build System <autodist@mambasoft.it> 2015.05.03-1mamba
- automatic update by autodist

* Sat Apr 04 2015 Automatic Build System <autodist@mambasoft.it> 2015.04.01-1mamba
- automatic update by autodist

* Sat Mar 21 2015 Automatic Build System <autodist@mambasoft.it> 2015.03.19-1mamba
- automatic update by autodist

* Thu Feb 05 2015 Automatic Build System <autodist@mambasoft.it> 2015.02.04-1mamba
- automatic update by autodist

* Sat Jan 31 2015 Automatic Build System <autodist@mambasoft.it> 2015.01.27-1mamba
- automatic update by autodist

* Fri Dec 26 2014 Automatic Build System <autodist@mambasoft.it> 2014.12.17-1mamba
- automatic update by autodist

* Tue Nov 25 2014 Automatic Build System <autodist@mambasoft.it> 2014.11.12-1mamba
- automatic update by autodist

* Wed Oct 22 2014 Automatic Build System <autodist@mambasoft.it> 2014.10.21-1mamba
- automatic update by autodist

* Sat Oct 18 2014 Automatic Build System <autodist@mambasoft.it> 2014.10.16-1mamba
- automatic update by autodist

* Mon Oct 13 2014 Automatic Build System <autodist@mambasoft.it> 2014.10.07-1mamba
- automatic update by autodist

* Fri Sep 19 2014 Automatic Build System <autodist@mambasoft.it> 2014.09.11-1mamba
- automatic update by autodist

* Wed Jul 23 2014 Automatic Build System <autodist@mambasoft.it> 2014.07.18-1mamba
- automatic update by autodist

* Fri Jul 11 2014 Automatic Build System <autodist@mambasoft.it> 2014.07.04-1mamba
- automatic update by autodist

* Wed May 28 2014 Automatic Build System <autodist@mambasoft.it> 2014.05.27-1mamba
- automatic update by autodist

* Tue Sep 10 2013 Automatic Build System <autodist@mambasoft.it> 2013.09.08-1mamba
- automatic update by autodist

* Mon Sep 02 2013 Automatic Build System <autodist@mambasoft.it> 2013.08.31-1mamba
- automatic update by autodist

* Wed Aug 28 2013 Automatic Build System <autodist@mambasoft.it> 2013.08.28-1mamba
- automatic update by autodist

* Tue Aug 13 2013 Automatic Build System <autodist@mambasoft.it> 2013.08.05-1mamba
- automatic update by autodist

* Thu Jun 27 2013 Automatic Build System <autodist@mambasoft.it> 2013.06.18-1mamba
- automatic version update by autodist

* Tue Jun 18 2013 Automatic Build System <autodist@mambasoft.it> 2013.06.14-1mamba
- automatic version update by autodist

* Tue Jun 11 2013 Automatic Build System <autodist@mambasoft.it> 2013.06.06-1mamba
- automatic version update by autodist

* Tue May 28 2013 Automatic Build System <autodist@mambasoft.it> 2013.04.30-1mamba
- automatic version update by autodist

* Mon Apr 15 2013 Automatic Build System <autodist@mambasoft.it> 2013.04.08-1mamba
- automatic version update by autodist

* Mon Apr 01 2013 Automatic Build System <autodist@mambasoft.it> 2013.04.01-1mamba
- automatic version update by autodist

* Tue Mar 12 2013 Automatic Build System <autodist@mambasoft.it> 2013.03.07-1mamba
- automatic version update by autodist

* Fri Mar 01 2013 Automatic Build System <autodist@mambasoft.it> 2013.02.27-1mamba
- automatic version update by autodist

* Wed Jan 23 2013 Automatic Build System <autodist@mambasoft.it> 2013.01.23-1mamba
- automatic version update by autodist

* Sat Jan 19 2013 Automatic Build System <autodist@mambasoft.it> 2013.01.18-1mamba
- automatic version update by autodist

* Sat Jan 12 2013 Automatic Build System <autodist@mambasoft.it> 2013.01.05-1mamba
- automatic version update by autodist

* Sat Nov 24 2012 Automatic Build System <autodist@mambasoft.it> 2012.11.22-1mamba
- automatic version update by autodist

* Tue Sep 04 2012 Automatic Build System <autodist@mambasoft.it> 2012.08.31-1mamba
- automatic version update by autodist

* Tue Apr 03 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2012.03.22-2mamba
- move headers from /usr/lib/live/*/include to /usr/include

* Mon Apr 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2012.03.22-1mamba
- update to 2012.03.22

* Mon Jul 25 2011 Automatic Build System <autodist@mambasoft.it> 2011.07.21-1mamba
- automatic version update by autodist

* Mon Jun 20 2011 Automatic Build System <autodist@mambasoft.it> 2011.06.16-1mamba
- automatic update by autodist

* Fri May 20 2011 Automatic Build System <autodist@mambasoft.it> 2011.03.14-1mamba
- automatic update by autodist

* Mon Mar 07 2011 Automatic Build System <autodist@mambasoft.it> 2011.03.05-1mamba
- automatic update by autodist

* Tue Feb 01 2011 Automatic Build System <autodist@mambasoft.it> 2011.01.24-1mamba
- automatic update by autodist

* Wed Jan 05 2011 Automatic Build System <autodist@mambasoft.it> 2011.01.05-1mamba
- automatic update by autodist

* Thu Dec 16 2010 Automatic Build System <autodist@mambasoft.it> 2010.12.14-1mamba
- automatic update by autodist

* Thu Dec 09 2010 Automatic Build System <autodist@mambasoft.it> 2010.12.05-1mamba
- automatic update by autodist

* Tue Nov 09 2010 Automatic Build System <autodist@mambasoft.it> 2010.11.08-1mamba
- automatic update by autodist

* Mon Aug 16 2010 Automatic Build System <autodist@mambasoft.it> 2010.07.29-1mamba
- automatic update by autodist

* Fri Jul 09 2010 Automatic Build System <autodist@mambasoft.it> 2010.07.07-1mamba
- automatic update by autodist

* Sat Jun 26 2010 Automatic Build System <autodist@mambasoft.it> 2010.06.22-1mamba
- automatic update by autodist

* Sat Apr 17 2010 Automatic Build System <autodist@mambasoft.it> 2010.04.09-1mamba
- automatic update by autodist

* Fri Jan 15 2010 Automatic Build System <autodist@mambasoft.it> 2010.01.13-1mamba
- automatic update by autodist

* Wed Jul 15 2009 Automatic Build System <autodist@mambasoft.it> 2009.07.09-1mamba
- automatic update by autodist

* Tue Aug 19 2008 gil <puntogil@libero.it> 2008.07.25-1mamba
- update to 2008.07.25
- renamed the spec file liblive
- fixed: url source group vendor distribution packager
- added: post postun
- installs binary type tests and servers  (see spec file) all in /usr/lib/live
- WARNING ** NOT TESTED **

* Mon Jun 27 2005 Alessandro Ramazzina <alessandro.ramazzina@qilinux.it> 2005.06.16-2qilnx
- rebuild and moved from devel-contrib repository to devel repository

* Sat Jun 25 2005 Matteo Bernasconi <voyagernm@virgilio.it> 2005.06.16-1qilnx
- First Build
